@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: David Zeuthen <davidz@redhat.com>
  */
@@ -1097,5 +1097,5 @@ g_vfs_backend_cdda_class_init (GVfsBackendCddaClass *klass)
 void
 g_vfs_cdda_daemon_init (void)
 {
-  g_set_application_name (_("Audio CD Filesystem Service"));
+  g_set_application_name (_("Audio CD File System Service"));
 }
