@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
  */
@@ -27,8 +27,6 @@
 #include <glib/gstdio.h>
 #include <locale.h>
 #include <stdlib.h>
-/*  TODO: remove + remove traces in Makefile.am  */
-#include <dbus/dbus.h>
 #include "metatree.h"
 #include "gvfsdaemonprotocol.h"
 #include "metadata-dbus.h"
